@@ -1,7 +1,7 @@
 package Log::Dispatch::FileWriteRotate;
 
-our $DATE = '2016-01-19'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-02'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -58,7 +58,7 @@ Log::Dispatch::FileWriteRotate - Log to files that archive/rotate themselves, w/
 
 =head1 VERSION
 
-This document describes version 0.04 of Log::Dispatch::FileWriteRotate (from Perl distribution Log-Dispatch-FileWriteRotate), released on 2016-01-19.
+This document describes version 0.05 of Log::Dispatch::FileWriteRotate (from Perl distribution Log-Dispatch-FileWriteRotate), released on 2016-10-02.
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Log-Dispat
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Log-Dispatch-FileWriteRotate>.
+Source repository is at L<https://github.com/sharyanto/perl-Log-Dispatch-FileWriteRotate>.
 
 =head1 BUGS
 
@@ -122,6 +122,8 @@ L<Log::Dispatch>
 
 L<File::Write::Rotate>
 
+L<Log::Dispatch::FileRotate>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
